# Climix

A climate index thing.

## Reference Data

We use [git-lfs](https://git-lfs.github.com/) to manage reference datasets. For
this to work, you need to have git-lfs installed and setup.

### Installing git-lfs

You can install git-lfs with conda via
```
conda install git-lfs
```
or with yum via
```
sudo yum install git-lfs
```

### Setting up git-lfs

For git-lfs to work, you also need to execute
```
git lfs install
```
This needs to be done only once after the installation.
